
#include <string.h>
#include <objbase.h>
#include "tts_tool.h"
#include "spres.h"

// forward declaration
LRESULT CALLBACK MainWndProc(HWND hwnd, UINT msg, WPARAM wParam, LPARAM lParam);

static BOOL InitApplication(HINSTANCE hInst)
{
	WNDCLASS wc;

	memset(&wc,0,sizeof(WNDCLASS));
	wc.style 			= CS_HREDRAW|CS_VREDRAW |CS_DBLCLKS ;
	wc.lpfnWndProc 		= (WNDPROC)MainWndProc;
	wc.hInstance 		= hInst;
	wc.hbrBackground 	= (HBRUSH)(COLOR_WINDOW+1);
	wc.lpszClassName 	= "SpeechWndClass";
	wc.lpszMenuName 	= MAKEINTRESOURCE(IDMAINMENU);
	wc.hCursor 			= LoadCursor(NULL,IDC_ARROW);
	wc.hIcon 			= LoadIcon(NULL,IDI_APPLICATION);
	if (!RegisterClass(&wc))
		return 0;

	return 1;
}

int WINAPI WinMain(HINSTANCE hInstance, HINSTANCE hPrevInstance, LPSTR lpCmdLine, INT nCmdShow)
{
	MSG msg;

	if(!InitApplication(hInstance))
		return 0;

	HWND hwndMain = CreateWindowEx(0, "SpeechWndClass","Speech",
		WS_OVERLAPPEDWINDOW,
		CW_USEDEFAULT,0,CW_USEDEFAULT,0,
		NULL,
		NULL,
		hInstance,
		NULL);

	if(!hwndMain)
		return 0;

	CoInitialize(NULL);

	ShowWindow(hwndMain, SW_SHOW);

	while (GetMessage(&msg, NULL, 0, 0)) {
		TranslateMessage(&msg);
		DispatchMessage(&msg);
	}

	CoUninitialize();

	return 0;

}

LRESULT CALLBACK MainWndProc(HWND hwnd, UINT msg, WPARAM wParam, LPARAM lParam)
{
	static TTS tts = NULL;	// make static so that it retains values between calls to this function
	TTSENUM en;
	TTSMODEINFOW info;
	char stg[256];

	switch (msg) {
	case WM_COMMAND:
		switch (LOWORD(wParam)){
		case IDM_DOSPEACH:
			if(tts){ 			// delete any previous TTS
				tts_Delete(tts);
				tts = NULL;
			}

			strcpy(stg,"This is an example of using the Text to Speech API version four.");

			if ( (en = tts_EnumCreate()) != NULL )
			{
				if ( tts_EnumReset(en) )
				{
					while ( tts_EnumNext(en,&info) )
					{
						tts = tts_Create(&info, NULL);
						if (tts!= NULL){
							tts_SetVolume(tts, 100);
							tts_SetPitch(tts, 10);
							tts_TextOut(tts, stg);
						}else{
							MessageBox(NULL,"OOPS!","Error!", MB_OK | MB_ICONINFORMATION | MB_SYSTEMMODAL);
						}
					}
				}
				tts_EnumDelete(en);
			}
			return 0;
		}
		case IDM_EXIT:
			SendMessage(hwnd, WM_CLOSE, 0, 0);
		break;

	case WM_DESTROY:
		if(tts) tts_Delete(tts); // delete last TTS on termination
		PostQuitMessage(0);
		break;

	default:
		return DefWindowProc(hwnd, msg, wParam, lParam);
	}
	return 0;
}

